# Plugin ocr_translate_easyocr

This is a plugin for the [ocr_translate](https://github.com/Crivella/ocr_translate).
Plugins to enable usage of Easyocr in ocr_translate

## Usage

- Install this by running `pip install ocr_translate-easyocr`
- Add `ocr_translate_easyocr` to your `INSTALLED_APPS` in `settings.py`
- Run the server with `AUTOCREATE_VALIDATED_MODELS` once
